..  Titling
    ##++::==~~--''``

.. _formats:

Formatters
::::::::::

Downstream systems ingest transformed survey data in several formats.

Formatter classes are stateless namespaces for functions which convert survey data
to those downstream formats.

.. automodule:: sdx.common.formats.cs_formatter

.. autoclass:: sdx.common.formats.cs_formatter.CSFormatter
   :members:
   :member-order: bysource
